# Useless Utilities!
## A collection of different bases such as ternary, quaternary, quinary and senary.

I do Plan to add more bases in the future.

## Usage:

use the corresponding function to convert to the base you want.
Such as:

ter(N) for ternary

quat(N) for quaternary

quin(N) for quinary

sen(N) for senary

sept(N) for septenary

non(N) for nonary

## Expected releases:
### Duodecimal
A base-12 number system. Ddec(N)
### Tridecimal
A base-13 number system. Tdec(N)
### Quattuordecimal
A base-14 number system. Qdec(N)
### Quindecimal
A base-15 number system. Qudec(N)


# Changelog:

## V1.0.0:
- Initial release
- Included ternary, quaternary, quinary and senary
- Deleted due to inconsistancies

## V1.0.1:
- Fixed a bug with the senary function
- Added a changelog
- Fixed the inconsistancies in V1.0.0
- Fixed email address

## V1.0.2:
- Renamed some variables to better fit the base

## V1.1.0:
- Added septenary
- Added mathematical functionality such as: addition, subtraction, multiplication, division and modulus

## V1.1.5:
- Added nonary
- added cli functionality (currently only -h/--help and -v/--version)